# Utility NSIS Script
#
# Prepared by Quib Mask
# Inspired by John T. Haller of PortableApps.com
#
# Last compiled with Nullsoft Scriptable Install System version 2.31
# http://nsis.sourceforge.net/Main_Page
#
# Uses FindProcDLL.dll version 2nd June 2004
# http://nsis.sourceforge.net/Find_Process_By_Name
#
# [QM]
#
# No Copyright. No Company.
# ========================================================================================

;symbols

!define NAME "TopOCRPocket"
!define PROGRAM "TopOCR"
!define VERSION "1.0.0.0"
!define EXECUTABLE "topocr.exe"

# Program Details
Name "${PROGRAM} Pocket"
OutFile "${NAME}.exe"
Caption "${PROGRAM} Pocket"
VIProductVersion "${VERSION}"
VIAddVersionKey ProductName "${PROGRAM} Pocket"
VIAddVersionKey Comments "Allows ${PROGRAM} to be run from a removable drive."
VIAddVersionKey CompanyName "None"
VIAddVersionKey LegalCopyright "None"
VIAddVersionKey FileDescription "${PROGRAM} Pocket"
VIAddVersionKey FileVersion "${VERSION}"
VIAddVersionKey ProductVersion "${VERSION}"
VIAddVersionKey InternalName "${PROGRAM} Pocket"
VIAddVersionKey OriginalFilename "${NAME}.exe"

# Runtime Switches
CRCCheck On
WindowIcon Off
SilentInstall Silent
AutoCloseWindow True
RequestExecutionLevel user

# Program Icon
Icon "${NAME}.ico"

;end

# ========================================================================================

;code

Section "Main"
	# Check if already running
	System::Call 'kernel32::CreateMutexA(i 0, i 0, t "${NAME}") i .r1 ?e'
	Pop $0
	StrCmp $0 0 "" ProgramRunning

;ProgramCheck:
	# Check for the executable file
	IfFileExists "$EXEDIR\${EXECUTABLE}" ProgramFound

	# Program executable not found
	MessageBox MB_OK|MB_ICONEXCLAMATION "${EXECUTABLE} was not found. Please check your configuration."
	Abort

ProgramFound:
	# Check if running
	FindProcDLL::FindProc "${EXECUTABLE}"
	StrCmp $R0 "1" "" SettingsBackup

ProgramRunning:
	MessageBox MB_OK|MB_ICONINFORMATION "Another instance of ${PROGRAM} is already running."
	Abort

# ........................................................................................

SettingsBackup:
	IfFileExists "$WINDIR\${PROGRAM}-Backup.ini" SettingsPrepare
	IfFileExists "$WINDIR\${PROGRAM}.ini" "" SettingsPrepare
	Rename "$WINDIR\${PROGRAM}.ini" "$WINDIR\${PROGRAM}-Backup.ini"

SettingsPrepare:
	IfFileExists "$EXEDIR\${PROGRAM}.ini" "" ProgramStart
	CopyFiles /SILENT "$EXEDIR\${PROGRAM}.ini" "$WINDIR\${PROGRAM}.ini"

# ........................................................................................

ProgramStart:
	ExecWait `"$EXEDIR\${EXECUTABLE}"`

# ........................................................................................

;SettingsSave:
	IfFileExists "$WINDIR\${PROGRAM}.ini" "" SettingsRestore
	CopyFiles /SILENT "$WINDIR\${PROGRAM}.ini" "$EXEDIR\${PROGRAM}.ini"
	Delete "$WINDIR\${PROGRAM}.ini"

SettingsRestore:
	IfFileExists "$WINDIR\${PROGRAM}-Backup.ini" "" Exit
	Rename "$WINDIR\${PROGRAM}-Backup.ini" "$WINDIR\${PROGRAM}.ini"

Exit:

SectionEnd
;end
